@@ -114,7 +114,7 @@ def create_tfrecords_from_csv(data_dir, csv_path, outputfilename, IMAGE_SIZE = (
 
 
 @affirmationcsv
-def create_split_tfrecords_from_csv(data_dir, csv, outfile1name, outfile2name, split_size_ratio , IMAGE_SIZE = (192,192)):
+def create_split_tfrecords_from_csv(data_dir, csv_path, outfile1name, outfile2name, split_size_ratio , IMAGE_SIZE = (192,192)):
 	
 	import pandas as pd
 	df = pd.read_csv(csv_path)
